@@ -327,7 +327,7 @@ class KubeModel(ABC):
         self.__load_model()
         self._load_optimizer_redis()
         self._load_redis_test()
-        #self._load_file_test()
+        self._load_file_test()
 
         #self._load_optimizer_state()
 
